@@ -209,6 +209,12 @@ class ProxyManager:
     def __exit__(self, exc_type, exc_val, exc_tb):
         self.stop()
 
+    async def __aenter__(self):
+        return self.__enter__()
+
+    async def __aexit__(self, exc_type, exc_val, exc_tb):
+        self.__exit__(exc_type, exc_val, exc_tb)
+
 
 class SessionProxy(Session):
     def __init__(self, manager: ProxyManager, success_criterion):
